/*
 * avards.c: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <vdr/plugin.h>

#define MAX_MODES 6

class cMenuSetupAvards : public cMenuSetupPage {
private:
    cParameter tmpconfig;
    const char *modes[MAX_MODES];
protected:
    virtual void Store(void);
public:
    cMenuSetupAvards(void);
};
